from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .MixinAbstractFurnaceScreenHandler import MixinAbstractFurnaceScreenHandler
from .MixinRecipeBookWidget import MixinRecipeBookWidget
from .MixinFontManager import MixinFontManager
from .MixinChunkSelection import MixinChunkSelection
from .MixinLivingEntity import MixinLivingEntity
from .MixinClientConnection import MixinClientConnection
from .MixinMinecraftClient import MixinMinecraftClient
from .MixinInteractionEntity2 import MixinInteractionEntity2
from .MixinClientPlayNetworkHandler import MixinClientPlayNetworkHandler
from .MixinMerchantEntity import MixinMerchantEntity
from .MixinDisconnectedScreen import MixinDisconnectedScreen
from .MixinShulkerEntity import MixinShulkerEntity
from .MixinSplashOverlay import MixinSplashOverlay
from .MixinTrueTypeFont import MixinTrueTypeFont
from .MixinClientPlayerInteractionManager import MixinClientPlayerInteractionManager
from .MixinCreativeInventoryScreen import MixinCreativeInventoryScreen
from .MixinChatHud import MixinChatHud
from .MixinHandledScreen import MixinHandledScreen
from .MixinItemCooldownManager import MixinItemCooldownManager
from .MixinDisplayEntity import MixinDisplayEntity
from .MixinSoundSystem import MixinSoundSystem
from .MixinWorldRenderer import MixinWorldRenderer
from .MixinTranslationStorage import MixinTranslationStorage
from .MixinPlayerListHud import MixinPlayerListHud
from .MixinAbstractHorseEntity import MixinAbstractHorseEntity
from .MixinFishingBobberEntity import MixinFishingBobberEntity
from .MixinFontStorage import MixinFontStorage
from .IMixinInteractionEntity import IMixinInteractionEntity
from .MixinBossBarHud import MixinBossBarHud
from .MixinPlayerEntity import MixinPlayerEntity
from .MixinRecipeBookResults import MixinRecipeBookResults
from .MixinTridentEntity import MixinTridentEntity
from .MixinCreeperEntity import MixinCreeperEntity
from .MixinStyleSerializer import MixinStyleSerializer
from .MixinOcelotEntity import MixinOcelotEntity
from .MixinScreen import MixinScreen
from .MixinAllayEntity import MixinAllayEntity
from .MixinSignEditScreen import MixinSignEditScreen
from .MixinHungerManager import MixinHungerManager
from .MixinBoatEntity import MixinBoatEntity
from .MixinAdvancementManager import MixinAdvancementManager
from .MixinInteractionEntity import MixinInteractionEntity
from .IMixinEntity import IMixinEntity
from .MixinItemEnchantmentsComponent import MixinItemEnchantmentsComponent
from .MixinBlockPredicatesChecker import MixinBlockPredicatesChecker
from .MixinPackedIntegerArray import MixinPackedIntegerArray
from .MixinClientAdvancementManager import MixinClientAdvancementManager
from .MixinPhaseType import MixinPhaseType
from .MixinAbstractPiglinEntity import MixinAbstractPiglinEntity
from .MixinHorseScreen import MixinHorseScreen
from .MixinPalettedContainer import MixinPalettedContainer
from .MixinChatScreen import MixinChatScreen
from .MixinEntity2 import MixinEntity2
from .MixinLoomScreen import MixinLoomScreen
from .MixinSimpleOption import MixinSimpleOption
from .MixinResourcePackManager import MixinResourcePackManager
from .MixinClientWorld import MixinClientWorld
from .MixinDataTracker import MixinDataTracker
from .MixinTextFieldWidget import MixinTextFieldWidget
from .MixinBeaconScreen import MixinBeaconScreen
from .MixinItemCooldownEntry import MixinItemCooldownEntry
from .MixinEntity import MixinEntity
from .MixinFoxEntity import MixinFoxEntity
from .MixinAnvilScreen import MixinAnvilScreen
from .MixinMerchantScreen import MixinMerchantScreen
from .MixinHorseEntity import MixinHorseEntity
from .MixinCyclingButton import MixinCyclingButton
from .MixinStatHandler import MixinStatHandler
from .MixinMessageHandler import MixinMessageHandler
from .MixinAdvancementProgress import MixinAdvancementProgress
from .MixinPalettedContainerData import MixinPalettedContainerData

File = TypeVar("java.io.File")

