from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .TraceLine_Builder import TraceLine_Builder
from .GroupFilter_CountMatchFilter import GroupFilter_CountMatchFilter
from .Registrable import Registrable
from .Util import Util
from .History import History
from .OptionsField import OptionsField
from .Vec3D import Vec3D
from .TextOverlay import TextOverlay
from .CharCompareFilter import CharCompareFilter
from .LongField import LongField
from .CommandManager import CommandManager
from .IRecipeBookResults import IRecipeBookResults
from .RecipeInventory import RecipeInventory
from .Button import Button
from .Sorting_SortServiceByFileName import Sorting_SortServiceByFileName
from .IDraw2D import IDraw2D
from .DataGen import DataGen
from .TextInput import TextInput
from .Prism_typescript import Prism_typescript
from .DoubleField import DoubleField
from .InteractionProxy_Break_BreakBlockResult import InteractionProxy_Break_BreakBlockResult
from .BaseScriptContext_ScriptAssertionError import BaseScriptContext_ScriptAssertionError
from .IChunkSection import IChunkSection
from .Rect import Rect
from .InteractionProxy import InteractionProxy
from .TraceLine import TraceLine
from .FiltererComposed import FiltererComposed
from .RenderElement3D import RenderElement3D
from .IItemCooldownManager import IItemCooldownManager
from .ClientConfigV2 import ClientConfigV2
from .Prism_groovy import Prism_groovy
from .ColorMapSetting import ColorMapSetting
from .Vec2D import Vec2D
from .Line3D import Line3D
from .IPalettedContainer import IPalettedContainer
from .ColorMapSetting_ColorEntry import ColorMapSetting_ColorEntry
from .PlayerInput import PlayerInput
from .IFontManager import IFontManager
from .Line import Line
from .IRecipeBookWidget import IRecipeBookWidget
from .IBeaconScreen import IBeaconScreen
from .StringifyFilter import StringifyFilter
from .IHorseScreen import IHorseScreen
from .WrappedClassInstance_MethodSigParts import WrappedClassInstance_MethodSigParts
from .IFilter import IFilter
from .IPackedIntegerArray import IPackedIntegerArray
from .ChatHistoryManager import ChatHistoryManager
from .Inventory import Inventory
from .Line3D_Builder import Line3D_Builder
from .Sorting_SortByTriggerName import Sorting_SortByTriggerName
from .BaseWrappedException_HostLocation import BaseWrappedException_HostLocation
from .TranslationUtil import TranslationUtil
from .IntField import IntField
from .BaseListener import BaseListener
from .Surface import Surface
from .AutoCompleteSuggester import AutoCompleteSuggester
from .AbstractSettingContainer import AbstractSettingContainer
from .SelectorDropdownOverlay import SelectorDropdownOverlay
from .FileChooser_fileObj import FileChooser_fileObj
from .ServiceContainer import ServiceContainer
from .BlockStateFilter import BlockStateFilter
from .EnchantInventory import EnchantInventory
from .IMerchantScreen import IMerchantScreen
from .KeyMacrosScreen import KeyMacrosScreen
from .Rect_Builder import Rect_Builder
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder
from .History_TabLinesKeepCursor import History_TabLinesKeepCursor
from .History_HistoryStep import History_HistoryStep
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .Scrollbar import Scrollbar
from .BooleanCompareFilter import BooleanCompareFilter
from .History_Add import History_Add
from .FileChooser_sortFile import FileChooser_sortFile
from .CraftingInventory import CraftingInventory
from .EventRegistry import EventRegistry
from .EventFilterer import EventFilterer
from .Websocket import Websocket
from .ScriptTrigger import ScriptTrigger
from .Plane3D import Plane3D
from .Sorting_SortServiceByRunning import Sorting_SortServiceByRunning
from .DocletDeclareType import DocletDeclareType
from .StoneCutterInventory import StoneCutterInventory
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .ServiceListTopbar import ServiceListTopbar
from .TickSync_TickSyncInt import TickSync_TickSyncInt
from .CustomImage import CustomImage
from .IClientPlayerInteractionManager import IClientPlayerInteractionManager
from .Event import Event
from .KeyListener import KeyListener
from .BrewingStandInventory import BrewingStandInventory
from .BasicFilter import BasicFilter
from .ExtensionLoader import ExtensionLoader
from .VillagerInventory import VillagerInventory
from .CartographyInventory import CartographyInventory
from .BaseWrappedException import BaseWrappedException
from .PerExecLanguageLibrary import PerExecLanguageLibrary
from .Box_Builder import Box_Builder
from .NumberCompareFilter import NumberCompareFilter
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
from .ClassBuilder import ClassBuilder
from .CustomClickEvent import CustomClickEvent
from .TextBuilder import TextBuilder
from .FiltererBlockUpdate import FiltererBlockUpdate
from .IContainerParent import IContainerParent
from .StringMapSetting_StringEntry import StringMapSetting_StringEntry
from .BaseWrappedException_GuestLocation import BaseWrappedException_GuestLocation
from .FileChooser import FileChooser
from .Sorting_SortByEnabled import Sorting_SortByEnabled
from .Draw2DElement import Draw2DElement
from .Item_Builder import Item_Builder
from .FakeServerCommandSource import FakeServerCommandSource
from .InteractionProxy_Break import InteractionProxy_Break
from .PrimitiveSettingGroup import PrimitiveSettingGroup
from .LibraryBuilder import LibraryBuilder
from .Draw3D import Draw3D
from .Prism_kotlin import Prism_kotlin
from .FReflection_CombinedVariableClassLoader import FReflection_CombinedVariableClassLoader
from .TickSync import TickSync
from .ModLoader import ModLoader
from .EventChooser_EventObj import EventChooser_EventObj
from .Image_Builder import Image_Builder
from .StringField import StringField
from .BaseScriptContext_SleepRunnable import BaseScriptContext_SleepRunnable
from .MovementDummy import MovementDummy
from .IOverlayParent import IOverlayParent
from .Slider import Slider
from .ScriptScreen import ScriptScreen
from .IMinecraftClient import IMinecraftClient
from .WorldScannerBuilder import WorldScannerBuilder
from .Draw2D import Draw2D
from .FloatField import FloatField
from .StringMapSetting import StringMapSetting
from .FJsMacros_EventAndContext import FJsMacros_EventAndContext
from .Sorting_MacroSortMethod import Sorting_MacroSortMethod
from .CancelScreen_RTCSort import CancelScreen_RTCSort
from .NoStyleCodeCompiler import NoStyleCodeCompiler
from .AboutOverlay import AboutOverlay
from .CheckBoxContainer import CheckBoxContainer
from .IResourcePackManager import IResourcePackManager
from .ListContainer import ListContainer
from .DocletReplaceParams import DocletReplaceParams
from .PerLanguageLibrary import PerLanguageLibrary
from .BaseScriptContext import BaseScriptContext
from .Extension_ExtMatch import Extension_ExtMatch
from .NameUtil import NameUtil
from .Pair import Pair
from .ProxyBuilder import ProxyBuilder
from .IInventory import IInventory
from .IScreen import IScreen
from .TextPrompt import TextPrompt
from .Prism_json import Prism_json
from .FileHandler_FileLineIterator import FileHandler_FileLineIterator
from .ServiceScreen import ServiceScreen
from .CreativeInventory import CreativeInventory
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder
from .Extension import Extension
from .Surface_Builder import Surface_Builder
from .ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder import ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder
from .Line_Builder import Line_Builder
from .Mappings import Mappings
from .BaseLibrary import BaseLibrary
from .ICategoryTreeParent import ICategoryTreeParent
from .ServiceTrigger import ServiceTrigger
from .WrappedScript import WrappedScript
from .StringCompareFilter_FilterMethod import StringCompareFilter_FilterMethod
from .CommandNodeAccessor import CommandNodeAccessor
from .PrioryFiFoTaskQueue import PrioryFiFoTaskQueue
from .RenderElement import RenderElement
from .EventFilterer_Compound import EventFilterer_Compound
from .ClassWrapperFilter import ClassWrapperFilter
from .ContainerInventory import ContainerInventory
from .Text_Builder import Text_Builder
from .Image import Image
from .Sorting_ServiceSortMethod import Sorting_ServiceSortMethod
from .RenderElementBuilder import RenderElementBuilder
from .Item import Item
from .IMerchantEntity import IMerchantEntity
from .HorseInventory import HorseInventory
from .WorldScanner import WorldScanner
from .DefaultCodeCompiler import DefaultCodeCompiler
from .Pos2D import Pos2D
from .BlockFilter import BlockFilter
from .FiltererModulus import FiltererModulus
from .HTTPRequest import HTTPRequest
from .ISignEditScreen import ISignEditScreen
from .FileField import FileField
from .OrFilter import OrFilter
from .FKeyBind_KeyTracker import FKeyBind_KeyTracker
from .FiltererInverted import FiltererInverted
from .IAdvancedFilter import IAdvancedFilter
from .LibraryRegistry import LibraryRegistry
from .TickBasedEvents import TickBasedEvents
from .ILoomScreen import ILoomScreen
from .NotFilter import NotFilter
from .SettingsOverlay import SettingsOverlay
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
from .HTTPRequest_Response import HTTPRequest_Response
from .FiltererRecvPacket import FiltererRecvPacket
from .Prism_python import Prism_python
from .Pos3D import Pos3D
from .MacroScreen import MacroScreen
from .IScreenInternal import IScreenInternal
from .ExtensionClassLoader import ExtensionClassLoader
from .ICompare import ICompare
from .ConfigFolder import ConfigFolder
from .IBossBarHud import IBossBarHud
from .History_TabLines import History_TabLines
from .Mappings_MethodData import Mappings_MethodData
from .Profile import Profile
from .BaseEventRegistry import BaseEventRegistry
from .GroupFilter_NoneMatchFilter import GroupFilter_NoneMatchFilter
from .MacroListTopbar import MacroListTopbar
from .BooleanField import BooleanField
from .Prism_regex import Prism_regex
from .IPlayerListHud import IPlayerListHud
from .AnvilInventory import AnvilInventory
from .Prism_lua import Prism_lua
from .ClassBuilder_FieldBuilder_FieldInitializerBuilder import ClassBuilder_FieldBuilder_FieldInitializerBuilder
from .EventListener import EventListener
from .BaseProfile import BaseProfile
from .GrindStoneInventory import GrindStoneInventory
from .TPSData import TPSData
from .ConfirmOverlay import ConfirmOverlay
from .SynchronizedWeakHashSet import SynchronizedWeakHashSet
from .GroupFilter import GroupFilter
from .Neighbor import Neighbor
from .Text import Text
from .SmithingInventory import SmithingInventory
from .StringHashTrie import StringHashTrie
from .ConfigManager import ConfigManager
from .Sorting_SortServiceByName import Sorting_SortServiceByName
from .EventLockWatchdog import EventLockWatchdog
from .AndFilter import AndFilter
from .OverlayContainer import OverlayContainer
from .Alignable import Alignable
from .AbstractMapSettingContainer import AbstractMapSettingContainer
from .BaseLanguage import BaseLanguage
from .Mappings_ClassData import Mappings_ClassData
from .CategoryTreeContainer import CategoryTreeContainer
from .MultiElementContainer import MultiElementContainer
from .BeaconInventory import BeaconInventory
from .AutoCompleteSuggestion import AutoCompleteSuggestion
from .AnnotatedCheckBox import AnnotatedCheckBox
from .FiltererSendPacket import FiltererSendPacket
from .MacroContainer import MacroContainer
from .InteractionProxy_Target import InteractionProxy_Target
from .Sorting_SortServiceByEnabled import Sorting_SortServiceByEnabled
from .ProxyBuilder_ProxyReference import ProxyBuilder_ProxyReference
from .JsMacrosThreadPool_PoolThread import JsMacrosThreadPool_PoolThread
from .IChatHud import IChatHud
from .History_Replace import History_Replace
from .EntityTraceLine import EntityTraceLine
from .DocletIgnore import DocletIgnore
from .GroupFilter_AllMatchFilter import GroupFilter_AllMatchFilter
from .XorFilter import XorFilter
from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
from .StringCompareFilter import StringCompareFilter
from .EditorScreen import EditorScreen
from .Sorting_SortByFileName import Sorting_SortByFileName
from .BaseScreen import BaseScreen
from .IItemCooldownEntry import IItemCooldownEntry
from .Prism_ruby import Prism_ruby
from .JsMacros import JsMacros
from .EventMacrosScreen import EventMacrosScreen
from .Core import Core
from .CoreConfigV2 import CoreConfigV2
from .SelectCursor import SelectCursor
from .History_Remove import History_Remove
from .Websocket_Disconnected import Websocket_Disconnected
from .Prism_javascript import Prism_javascript
from .Box import Box
from .DocletReplaceTypeParams import DocletReplaceTypeParams
from .AbstractSettingField import AbstractSettingField
from .DocletReplaceReturn import DocletReplaceReturn
from .Option import Option
from .Library import Library
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .MethodWrapper import MethodWrapper
from .Prism import Prism
from .ProfileSetting import ProfileSetting
from .InteractionProxy_Interact import InteractionProxy_Interact
from .FileMapSetting import FileMapSetting
from .FileMapSetting_FileEntry import FileMapSetting_FileEntry
from .WrappedClassInstance import WrappedClassInstance
from .Mappings_MappedClass import Mappings_MappedClass
from .FJsMacros_ScriptEventListener import FJsMacros_ScriptEventListener
from .LoomInventory import LoomInventory
from .ServiceManager_ServiceStatus import ServiceManager_ServiceStatus
from .CancelScreen import CancelScreen
from .GroupFilter_AnyMatchFilter import GroupFilter_AnyMatchFilter
from .EntityTraceLine_Builder import EntityTraceLine_Builder
from .PerExecLibrary import PerExecLibrary
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
from .ServiceManager import ServiceManager
from .JsMacrosThreadPool import JsMacrosThreadPool
from .MovementQueue import MovementQueue
from .EventChooser import EventChooser
from .OptionType import OptionType
from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .PlayerInventory import PlayerInventory
from .TextStyleCompiler import TextStyleCompiler
from .Sorting import Sorting
from .FileHandler import FileHandler
from .ProfileSetting_ProfileEntry import ProfileSetting_ProfileEntry
from .IEventListener import IEventListener
from .Prism_clike import Prism_clike
from .FurnaceInventory import FurnaceInventory
from .IPalettedContainerData import IPalettedContainerData
from .ClassBuilder_BodyBuilder import ClassBuilder_BodyBuilder
from .History_ShiftLine import History_ShiftLine
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder
from .BossBarConsumer import BossBarConsumer
from .ScriptCodeCompiler import ScriptCodeCompiler
from .CommandBuilder import CommandBuilder
from .Draw2DElement_Builder import Draw2DElement_Builder
from .RunningContextContainer import RunningContextContainer

File = TypeVar("java.io.File")

