from typing import overload
from typing import TypeVar

net_minecraft_entity_data_TrackedData_java_util_Optional_net_minecraft_text_Text__ = TypeVar("net_minecraft_entity_data_TrackedData_java_util_Optional_net_minecraft_text_Text__")
TrackedData = net_minecraft_entity_data_TrackedData_java_util_Optional_net_minecraft_text_Text__


class MixinEntity2:

	@overload
	def getCustomNameKey(self) -> TrackedData:
		pass

	pass


