from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .EventEXPChange import EventEXPChange
from .EventCustom import EventCustom
from .EventRecvMessage import EventRecvMessage
from .EventWrappedScript import EventWrappedScript
from .EventAirChange import EventAirChange
from .EventSlotUpdate import EventSlotUpdate
from .CodeCompileEvent import CodeCompileEvent
from .EventResourcePackLoaded import EventResourcePackLoaded
from .EventMouseScroll import EventMouseScroll
from .EventItemDamage import EventItemDamage
from .EventTitle import EventTitle
from .EventOpenContainer import EventOpenContainer
from .EventBossbar import EventBossbar
from .EventAttackBlock import EventAttackBlock
from .EventDamage import EventDamage
from .EventPlayerLeave import EventPlayerLeave
from .EventChunkLoad import EventChunkLoad
from .EventHungerChange import EventHungerChange
from .EventHealthChange import EventHealthChange
from .EventDropSlot import EventDropSlot
from .EventRiding import EventRiding
from .EventEntityUnload import EventEntityUnload
from .EventJoinServer import EventJoinServer
from .EventLaunchGame import EventLaunchGame
from .EventEntityDamaged import EventEntityDamaged
from .EventStatusEffectUpdate import EventStatusEffectUpdate
from .EventFallFlying import EventFallFlying
from .EventDisconnect import EventDisconnect
from .EventInteractBlock import EventInteractBlock
from .EventSendPacket import EventSendPacket
from .EventHeal import EventHeal
from .EventInteractEntity import EventInteractEntity
from .EventBlockUpdate import EventBlockUpdate
from .EventContainerUpdate import EventContainerUpdate
from .EventEntityHealed import EventEntityHealed
from .EventClickSlot import EventClickSlot
from .EventDimensionChange import EventDimensionChange
from .EventItemPickup import EventItemPickup
from .EventQuitGame import EventQuitGame
from .EventOpenScreen import EventOpenScreen
from .EventDeath import EventDeath
from .EventRecvPacket import EventRecvPacket
from .EventAttackEntity import EventAttackEntity
from .EventSignEdit import EventSignEdit
from .EventSendMessage import EventSendMessage
from .CommandContextHelper import CommandContextHelper
from .EventTick import EventTick
from .EventSound import EventSound
from .EventKey import EventKey
from .EventProfileLoad import EventProfileLoad
from .EventService import EventService
from .EventEntityLoad import EventEntityLoad
from .EventChunkUnload import EventChunkUnload
from .EventNameChange import EventNameChange
from .EventArmorChange import EventArmorChange
from .EventPlayerJoin import EventPlayerJoin
from .EventHeldItemChange import EventHeldItemChange

File = TypeVar("java.io.File")

